.. pyrrhic-restic documentation master file, created by
   sphinx-quickstart on Sun Jul 24 13:39:36 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyrrhic-restic's documentation!
==========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   reference/modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
